#!/usr/bin/env bash

#-----------------------------------------------------------------------------
script_name=`basename $0`
#
# Version: x. major version, .y minor version.
version="2.0"
#
# Description:
#     License: BSD-3-Clause - https://opensource.org/license/bsd-3-clause
#      Author: XOMedia Support <support@xomedia.io>
#              https://xomedia.io/unix-script-template/
#        Deps: ---
#        Args: ---
#      Output: ---
#        BUGs: ---
#       NOTEs: ---
#
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# License:
#------------------------------------------------------------------------------
# Copyright (c) 2024, XOMedia, LLC All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this # list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation and
# /or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors
# maybe used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS”
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# CHANGELOG:
#
# [1.0]
# - 2010-11-14: Initial script.
# [2.0]
# - 2024-05-29: Rewrite.
#
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# TODO:
#
#------------------------------------------------------------------------------

# ------------------------------------------------------------------------------
# Initializations:
# ------------------------------------------------------------------------------
# Safe and sane environment with POSIX-y behavior:
#set -o posix  # Bash
umask 022
#PATH=${PATH}:/sbin:/usr/sbin:/bin:/usr/bin:/usr/contrib/bin:/usr/local/bin
#UNIX95=TRUE
#LANG=C
#export PATH UNIX95 LANG
#
# ------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Globals / CONFIG:
#------------------------------------------------------------------------------
# DEBUG:
# set -x  # Debug
# set -n  # Shell syntax check (without execution)
# set -v  # Verbose
#
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Sub Routines:
#------------------------------------------------------------------------------
usage() {
cat << EOF
USAGE
   ${script_name} [-hv] [-b <string>] [-g <string>]

         <string> First and last name

DESCRIPTION
   A script similiar to the traditional “Hello, World! program”.

   In Computer Science 101, the first program many students create is a simple
   one that outputs an iconic line of text: "Hello World!

OPTIONS
   -b name   Prints goodbye
   -g name   Prints hello
   -h        Help
   -v        Version info

EXAMPLES
   ${script_name} -g Jane
      Prints Hello Jane!

   ${script_name} -b John
      Prints Goodbye John!
EOF
}

# Arg handler: Using getopts shell built-in.
getargs() {
if (($# == 0))
then
   usage
   exit 1
fi
while getopts g:b:hv args
do
   case ${args} in
   b) GOODBYE=1
      name="${OPTARG}"
      ;;
   g) HELLO=1
      name="${OPTARG}"
      ;;
   h) usage ;;
   v) echo "${script_name} ${version} by XOMedia Support <support@xomedia.io>" ;;
   ?) echo "Invalid option(s)" >&2
      usage
      exit 1
      ;;
   esac
done
}

#------------------------------------------------------------------------------
# Main:
#------------------------------------------------------------------------------
# Quotes enable getopts to handle spaces.
getargs "${@}"

if ((${HELLO}))
then
   echo "Hello ${name}!"
elif ((${GOODBYE}))
then
   echo "Goodbye ${name}!"
fi

#EOF
